# FILE: makerules.tcl
#
# This file controls the application 'pimake' by defining rules which
# describe how to build the applications and/or extensions produced by
# the source code in this directory.
#
# Verify that this script is being sourced by pimake
if {[llength [info commands MakeRule]] == 0} {
    error "'[info script]' must be evaluated by pimake"
}
#
########################################################################

set mmdispObjects {
	display
	mmdinit
	mmdisp
}

set allObjects [concat avftoovf avftovio avftoave $mmdispObjects]

MakeRule Define {
    -targets            all
    -dependencies       [concat configure \
	        [Platform Executables {avftoovf avftovio avftoave}] \
                [Platform Specific appindex.tcl]]
}

MakeRule Define {
    -targets            configure
    -dependencies       [Platform Name]
}

MakeRule Define {
    -targets            [Platform Name]
    -dependencies       {}
    -script             {MakeDirectory [Platform Name]}
}

MakeRule Define {
    -targets            tclIndex
    -dependencies       [glob -nocomplain *.tcl]
    -script             {
                         MakeTclIndex .
                        }
}

# Could use better support for this:
MakeRule Define {
    -targets            [Platform Specific appindex.tcl]
    -dependencies       [Platform Executables mmdisp]
    -script             {puts "Updating [Platform Specific appindex.tcl]"
                        set f [open [Platform Specific appindex.tcl] w]
                        puts $f [format {
Oc_Application Define {
    -name               mmDisp
    -version            1.0.1.3
    -machine            %s
    -file               "%s"
}
                        } [Platform Name] \
                                [file tail [Platform Executables mmdisp]]]
                        close $f
                        }
}

MakeRule Define {
    -targets            [Platform Executables mmdisp]
    -dependencies       [concat [Platform Objects $mmdispObjects] \
			        [Platform StaticLibraries {vf nb oc}] \
			        [list [file join .. .. ext oc tclIndex] \
			        [file join .. .. ext ow tclIndex] \
			        [file join .. .. ext net tclIndex] \
			        [file join .. .. ext vf tclIndex] \
			        tclIndex]]
    -script		[format {
			    Platform Link -obj {%s} \
			            -lib {vf nb oc tk} \
			            -sub WINDOWS -out mmdisp
			} $mmdispObjects]
}

MakeRule Define {
    -targets            [Platform Executables avftoovf]
    -dependencies       [concat [Platform Objects avftoovf] \
			        [Platform StaticLibraries {vf nb oc}]]
    -script		[format {
			    Platform Link -obj {%s} \
			            -lib {vf nb oc tk} \
			            -sub WINDOWS -out avftoovf
			} avftoovf]
}

MakeRule Define {
    -targets            [Platform Executables avftovio]
    -dependencies       [concat [Platform Objects avftovio] \
			        [Platform StaticLibraries {vf nb oc}]]
    -script		[format {
			    Platform Link -obj {%s} \
			            -lib {vf nb oc tk} \
			            -sub WINDOWS -out avftovio
			} avftovio]
}

MakeRule Define {
    -targets            [Platform Executables avftoave]
    -dependencies       [concat [Platform Objects avftoave] \
			        [Platform StaticLibraries {vf nb oc}]]
    -script		[format {
			    Platform Link -obj {%s} \
			            -lib {vf nb oc tk} \
			            -sub WINDOWS -out avftoave
			} avftoave]
}

foreach o $allObjects { 
    MakeRule Define {
        -targets	[Platform Objects $o]
        -dependencies	[concat [list [Platform Name]] \
			        [[CSourceFile New _ $o.cc] Dependencies]]
        -script		[format {Platform Compile C++ -opt 1 \
			        -inc [[CSourceFile New _ %s.cc] DepPath] \
			        -src %s.cc -out %s
			} $o $o $o]
    }
}

MakeRule Define {
    -targets            distclean
    -dependencies       clean
    -script             {DeleteFiles [Platform Name]}
}
 
MakeRule Define {
    -targets            clean
    -dependencies       mostlyclean
}
 
MakeRule Define {
    -targets            mostlyclean
    -dependencies       objclean
    -script             {eval DeleteFiles [concat tclIndex \
	        [Platform Specific appindex.tcl] [Platform \
                Executables {avftoovf avftovio avftoave mmdisp}]]}
}
 
MakeRule Define {
    -targets            objclean
    -dependencies       {}
    -script             [format {
			    eval DeleteFiles [Platform Objects {%s}]
			} $allObjects]
}

unset allObjects
unset mmdispObjects
