/* FILE: imports.h                    -*-Mode: c++-*-
 *
 *	Directives to include header files from outside the extension.
 *
 * NOTICE: Plase see the file ../../LICENSE
 *
 * Last modified on: $Date: 1999/10/20 19:46:46 $
 * Last modified by: $Author: dgp $
 */

#ifndef _OC_IMPORTS
#define _OC_IMPORTS

#include "port.h"

/* Header files for third-party extension libraries */
#ifdef __cplusplus
// When compiling with a C++ compiler, need to force all declarations
// in tcl.h and tk.h to have "C" linkage.
extern "C" {
// Also, when compiling with a C++ compiler, create macro definitions
// in tcl.h and tk.h as would be suitable for a standard C compiler
// using stdarg.h.
#  ifndef HAS_STDARG
#    define HAS_STDARG
#  endif
#endif

#include <tcl.h>
#include <tk.h>

/* Header files for other OOMMF extension libraries */

/* End includes */     /* Optional directive to pimake */

#ifndef TCL_INTEGER_SPACE
#define TCL_INTEGER_SPACE 24
#endif

/*
 * The function type Tcl_PanicProc was introduced in Tcl 8.1b2
 */
#if (TCL_MAJOR_VERSION < 8) \
    || ((TCL_MAJOR_VERSION == 8) && (TCL_MINOR_VERSION == 0))
typedef void (Tcl_PanicProc) _ANSI_ARGS_(TCL_VARARGS(char *, format));
#endif

#ifdef __cplusplus
}
#endif

/*
 * In the tcl.h file released with Tcl 8.0.3 and Tcl 8.0.4, the
 * prototype for Tcl_AppInit is mistakenly declared with linkage
 * type __declspec(dllimport) on Windows platforms when tcl.h
 * is included in other apps, causing warnings from the MSVC
 * compiler.  The following declaration and macro work around
 * that bug.
 */

#if (TCL_MAJOR_VERSION == 8) && (TCL_MINOR_VERSION == 0) \
    && (TCL_RELEASE_LEVEL == 2) && (TCL_RELEASE_SERIAL > 2) \
    && (TCL_RELEASE_SERIAL < 5)
Tcl_AppInitProc Oc_AppInit;
#define Tcl_AppInit Oc_AppInit
#endif

/*
 * A pretty ugly hack to get around exit crashes in Tk 8.1.x on MS Windows.
 * The Tk Dll cleanup routines try to call Tcl_GetThreadData, but calls
 * to Tcl_* crash, unless the Tk DLL has called Tcl_InitStubs.  This is
 * normally done in Tk_Init, but since we're "statically" linking Tk,
 * we sometimes omit Tk_Init.  The routine Tk_Main also calls Tcl_InitStubs
 * form within the Tk DLL, so if we always call Tk_Main, we're safe.
 */
#if (SYSTEM_TYPE == WINDOWS) && (TK_MAJOR_VERSION == 8) \
        && (TK_MINOR_VERSION == 1) && (TK_RELEASE_LEVEL == 2) \
        && (TK_RELEASE_SERIAL < 2)
#define Tcl_Main Tk_Main
#endif

#endif /* _OC_IMPORTS */
